# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accountId: Optional[str]

adminApiKey: Optional[str]

apiKey: Optional[str]

apiUrl: Optional[str]

cacertFile: Optional[str]

infrastructureApiUrl: Optional[str]

insecureSkipVerify: Optional[bool]

insightsInsertKey: Optional[str]

insightsInsertUrl: Optional[str]

insightsQueryUrl: Optional[str]

nerdgraphApiUrl: Optional[str]

region: str
"""
The data center for which your New Relic account is configured. Only one region per provider block is permitted.
"""

syntheticsApiUrl: Optional[str]

